---
title: 쇼피파이(Shopify) 서비스 이용방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 플러그인
seo:
  title: 쇼피파이(Shopify) 서비스 이용방법
  description: >-
    Shopify(쇼피파이)는 포트원에서 제공하는 유료 서비스로, ‘코리아 포트원’과 계약 후 이용이 가능합니다. Shopify 서비스를
    통해 웹사이트 구축 시 필수적인 사용 가이드를 소개드립니다.
  keywords:
    - 쇼피파이
tags:
  - 공통
  - 플러그인
  - 쇼피파이
pgCompanies:
  - 공통
searchTags:
  - 글로벌
  - onboarding
  - Shopify
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="“Shopify(쇼피파이)”서비스를 통해 웹사이트 구축 시 이용방법을 안내드립니다." title="" />

### **서비스 소개**

Shopify(쇼피파이) 온라인 커머스 플랫폼 서비스로 포트원에서는 해외결제를 포함한 다양한 결제수단을 지원하는 포트원의 유료 커머스 플랫폼 플러그인 서비스입니다.

### **서비스 특징**

서비스 사용을 위해 포트원의 글로벌 관리자콘솔과 한국 관리자콘솔을 모두 이용해 주셔야 하며, Shopify(쇼피파이) 플러그인 이용 시 코리아 포트원과 계약을 맺으신 후 서비스 사용이 가능합니다.

### **비용 안내**

Shopify(쇼피파이)는 쇼피파이페이먼츠를 이용하지 않는 타사 거래의 경우 추가 수수료를 부과하나 포트원에서는 Shopify(쇼피파이)와의 전략적인 제휴를 통해 고객사에서 부담해야 하는 거래 수수료 비용을 대신 부담하여 저렴한 수수료율로 서비스 제공이 가능합니다.

- 서비스이용요금:  0.50% (minimum 500 USD) \
  (상세 수수료는 계약 진행시 안내됩니다)
- **요금 청구**
  - 서비스 이용 당월 요금을 산정하여 산정 내역서를 계약서에 기재해 주신 계약, 정산 담당자님의 이메일로 전달드립니다.
  - 서비스 이용 당월 이용요금에 대한 세금계산서를 익월 10일 이전에 고객사 정산 담당자 이메일로 전자세금계산서 청구 발행됩니다.
  - 세금계산서 작성일자는 이용 당월 말일 자입니다.
- **요금 지급**
  - 고객사는 세금계산서 발행 당월 말일까지 해당 대금을 주식회사 코리아포트원으로 지급합니다. \
    (계좌 정보는 이용 계약서 참고)

### 신청 방법

- 포트원 해외결제서비스 [도입문의](https://go.portone.io/l/1047343/2023-11-27/6rv/?_gl=1*19xamm*_gcl_au*MTk3NzM1MTQzMC4xNzE3NzMwMDU0*_ga*OTE5ODY1NzY1LjE3MDY3Nzk5MDA.*_ga_PD0FDL16NZ*MTcxODE4MDYwMy4xNDEuMS4xNzE4MTgyOTkzLjAuMC4w) 신청 해주시면 담당 매니저가 연락 드립니다.

<Callout icon="💡" title="참고사항" content="**KYC** **전** **운영** **사이트** **내** **필수** **요건**

1. 상품 등록 필수
2. 배송 정책 명시
3. 취소 및 환불 정책 명시
4. 주문(결제)페이지와 결제 기능 구현" />

### **연동가이드**

- [Shopify(쇼피파이) 연동 가이드 보러가기 ↗](https://developers.portone.io/opi/ko/extra/plugins/shopify/shopify/shopify-3?v=v1)
- [쇼피파이(Shopify) 지원 가능한 결제수단 보러가기 ↗](https://help.portone.io/content/shopify-available-list)
